@@ -17,7 +17,7 @@
 // Copyright (C) 2006, 2007 Jeff Muizelaar <jeff@infidigm.net>
 // Copyright (C) 2006 Carlos Garcia Campos <carlosgc@gnome.org>
 // Copyright (C) 2009 Koji Otani <sho@bbr.jp>
-// Copyright (C) 2009-2011, 2013, 2016-2020 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2009-2011, 2013, 2016-2021 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2010 Christian Feuersänger <cfeuersaenger@googlemail.com>
 // Copyright (C) 2011 Andrea Canciani <ranma42@gmail.com>
 // Copyright (C) 2011-2014, 2016, 2020 Thomas Freitag <Thomas.Freitag@alfa.de>
@@ -25,7 +25,7 @@
 // Copyright (C) 2015, 2017, 2020 Adrian Johnson <ajohnson@redneon.com>
 // Copyright (C) 2017, 2019 Oliver Sander <oliver.sander@tu-dresden.de>
 // Copyright (C) 2018 Adam Reichold <adam.reichold@t-online.de>
-// Copyright (C) 2020 Philipp Knechtges <philipp-dev@knechtges.com>
+// Copyright (C) 2020, 2021 Philipp Knechtges <philipp-dev@knechtges.com>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -36,6 +36,7 @@
 #define GFXSTATE_H
 
 #include "poppler-config.h"
+#include "poppler_private_export.h"
 
 #include "Object.h"
 #include "Function.h"
@@ -216,7 +217,7 @@ enum GfxColorSpaceMode
 typedef std::shared_ptr<void> GfxLCMSProfilePtr;
 
 #ifdef USE_CMS
-GfxLCMSProfilePtr make_GfxLCMSProfilePtr(void *profile);
+GfxLCMSProfilePtr POPPLER_PRIVATE_EXPORT make_GfxLCMSProfilePtr(void *profile);
 #endif
 
 // wrapper of cmsHTRANSFORM to copy
@@ -241,7 +242,7 @@ private:
     unsigned int transformPixelType;
 };
 
-class GfxColorSpace
+class POPPLER_PRIVATE_EXPORT GfxColorSpace
 {
 public:
     GfxColorSpace();
@@ -313,7 +314,7 @@ protected:
 // GfxDeviceGrayColorSpace
 //------------------------------------------------------------------------
 
-class GfxDeviceGrayColorSpace : public GfxColorSpace
+class POPPLER_PRIVATE_EXPORT GfxDeviceGrayColorSpace : public GfxColorSpace
 {
 public:
     GfxDeviceGrayColorSpace();
@@ -379,7 +380,6 @@ private:
     double whiteX, whiteY, whiteZ; // white point
     double blackX, blackY, blackZ; // black point
     double gamma; // gamma value
-    double kr, kg, kb; // gamut mapping mulitpliers
     void getXYZ(const GfxColor *color, double *pX, double *pY, double *pZ) const;
 #ifdef USE_CMS
     std::shared_ptr<GfxColorTransform> transform;
@@ -390,7 +390,7 @@ private:
 // GfxDeviceRGBColorSpace
 //------------------------------------------------------------------------
 
-class GfxDeviceRGBColorSpace : public GfxColorSpace
+class POPPLER_PRIVATE_EXPORT GfxDeviceRGBColorSpace : public GfxColorSpace
 {
 public:
     GfxDeviceRGBColorSpace();
@@ -460,7 +460,6 @@ private:
     double blackX, blackY, blackZ; // black point
     double gammaR, gammaG, gammaB; // gamma values
     double mat[9]; // ABC -> XYZ transform matrix
-    double kr, kg, kb; // gamut mapping mulitpliers
     void getXYZ(const GfxColor *color, double *pX, double *pY, double *pZ) const;
 #ifdef USE_CMS
     std::shared_ptr<GfxColorTransform> transform;
@@ -471,7 +470,7 @@ private:
 // GfxDeviceCMYKColorSpace
 //------------------------------------------------------------------------
 
-class GfxDeviceCMYKColorSpace : public GfxColorSpace
+class POPPLER_PRIVATE_EXPORT GfxDeviceCMYKColorSpace : public GfxColorSpace
 {
 public:
     GfxDeviceCMYKColorSpace();
@@ -539,7 +538,6 @@ private:
     double whiteX, whiteY, whiteZ; // white point
     double blackX, blackY, blackZ; // black point
     double aMin, aMax, bMin, bMax; // range for the a and b components
-    double kr, kg, kb; // gamut mapping mulitpliers
     void getXYZ(const GfxColor *color, double *pX, double *pY, double *pZ) const;
 #ifdef USE_CMS
     std::shared_ptr<GfxColorTransform> transform;
@@ -550,7 +548,7 @@ private:
 // GfxICCBasedColorSpace
 //------------------------------------------------------------------------
 
-class GfxICCBasedColorSpace : public GfxColorSpace
+class POPPLER_PRIVATE_EXPORT GfxICCBasedColorSpace : public GfxColorSpace
 {
 public:
     GfxICCBasedColorSpace(int nCompsA, GfxColorSpace *altA, const Ref *iccProfileStreamA);
@@ -881,7 +879,7 @@ public:
     bool getHasBBox() const { return hasBBox; }
 
 protected:
-    bool init(GfxResources *res, Dict *dict, OutputDev *out, GfxState *state);
+    virtual bool init(GfxResources *res, Dict *dict, OutputDev *out, GfxState *state);
 
     // 1: Function-based shading
     // 2: Axial shading
@@ -902,7 +900,7 @@ protected:
 // GfxUnivariateShading
 //------------------------------------------------------------------------
 
-class GfxUnivariateShading : public GfxShading
+class POPPLER_PRIVATE_EXPORT GfxUnivariateShading : public GfxShading
 {
 public:
     GfxUnivariateShading(int typeA, double t0A, double t1A, std::vector<std::unique_ptr<Function>> &&funcsA, bool extend0A, bool extend1A);
@@ -925,6 +923,9 @@ public:
 
     virtual double getDistance(double sMin, double sMax) const = 0;
 
+protected:
+    bool init(GfxResources *res, Dict *dict, OutputDev *out, GfxState *state) override;
+
 private:
     double t0, t1;
     std::vector<std::unique_ptr<Function>> funcs;
@@ -940,7 +941,7 @@ private:
 // GfxFunctionShading
 //------------------------------------------------------------------------
 
-class GfxFunctionShading : public GfxShading
+class POPPLER_PRIVATE_EXPORT GfxFunctionShading : public GfxShading
 {
 public:
     GfxFunctionShading(double x0A, double y0A, double x1A, double y1A, const double *matrixA, std::vector<std::unique_ptr<Function>> &&funcsA);
@@ -963,6 +964,9 @@ public:
     const Function *getFunc(int i) const { return funcs[i].get(); }
     void getColor(double x, double y, GfxColor *color) const;
 
+protected:
+    bool init(GfxResources *res, Dict *dict, OutputDev *out, GfxState *state) override;
+
 private:
     double x0, y0, x1, y1;
     double matrix[6];
@@ -1043,7 +1047,7 @@ struct GfxGouraudVertex
     GfxColor color;
 };
 
-class GfxGouraudTriangleShading : public GfxShading
+class POPPLER_PRIVATE_EXPORT GfxGouraudTriangleShading : public GfxShading
 {
 public:
     GfxGouraudTriangleShading(int typeA, GfxGouraudVertex *verticesA, int nVerticesA, int (*trianglesA)[3], int nTrianglesA, std::vector<std::unique_ptr<Function>> &&funcsA);
@@ -1090,6 +1094,9 @@ public:
 
     void getParameterizedColor(double t, GfxColor *color) const;
 
+protected:
+    bool init(GfxResources *res, Dict *dict, OutputDev *out, GfxState *state) override;
+
 private:
     GfxGouraudVertex *vertices;
     int nVertices;
@@ -1132,7 +1139,7 @@ struct GfxPatch
     ColorValue color[2][2];
 };
 
-class GfxPatchMeshShading : public GfxShading
+class POPPLER_PRIVATE_EXPORT GfxPatchMeshShading : public GfxShading
 {
 public:
     GfxPatchMeshShading(int typeA, GfxPatch *patchesA, int nPatchesA, std::vector<std::unique_ptr<Function>> &&funcsA);
@@ -1168,6 +1175,9 @@ public:
 
     void getParameterizedColor(double t, GfxColor *color) const;
 
+protected:
+    bool init(GfxResources *res, Dict *dict, OutputDev *out, GfxState *state) override;
+
 private:
     GfxPatch *patches;
     int nPatches;
@@ -1178,7 +1188,7 @@ private:
 // GfxImageColorMap
 //------------------------------------------------------------------------
 
-class GfxImageColorMap
+class POPPLER_PRIVATE_EXPORT GfxImageColorMap
 {
 public:
     // Constructor.
@@ -1310,7 +1320,7 @@ private:
     GfxSubpath(const GfxSubpath *subpath);
 };
 
-class GfxPath
+class POPPLER_PRIVATE_EXPORT GfxPath
 {
 public:
     // Constructor.
@@ -1372,7 +1382,7 @@ private:
 // GfxState
 //------------------------------------------------------------------------
 
-class GfxState
+class POPPLER_PRIVATE_EXPORT GfxState
 {
 public:
     /**
